@@ -1,5 +1,5 @@
 {
-    "type": {"required": True, "type": "string", "regex": "(?i)^(prog|sys|bd)$"},
+    "type": {"required": True, "type": "string", "regex": "(?i)^(prog|sys|bd|vcs)$"},
     "niveau": {"required": False, "type": "string"},
     "titre": {"required": False, "type": "string"},
     "objectif": {"required": False, "type": "string"},
@@ -8,4 +8,5 @@
     "auteur": {"required": False, "type": "string"},
     "licence": {"required": False, "type": "string"},
     "rétroactions": {"required": False, "type": "dict", "schema": "rétroactions"},
+    "ttl": {"required": False, "type": "integer"},
 }
